@@ -7,25 +7,34 @@
 #' @family Tools
 #' @family Credentials
 #' @param from,to,cc,bcc Character. Emails
-#' @param subject Character. Subject for the email
-#' @param text,html Character. Text or HTML to send in the body
+#' @param subject Character. Subject for the email.
+#' @param text,html Character. Text or HTML to send in the body.
 #' @param attachment Character, plot or data.frame. Will send the file, 
 #' plot as PNG or data.frame as CSV, respectively. 
 #' @param service Character. Service platform to search on \code{creds}.
 #' @param creds Character. Credential's user (see \code{get_creds()}).
-#' Must contain: url (POST address), api (api key)
+#' Must contain: url (POST address), api (API key).
 #' @param quiet Boolean. Keep quite or display messages?
 #' @return No return value, called for side effects.
+#' @examples
+#' \dontrun{
+#' myPlot <- noPlot("My plot")
+#' mailSend(from = "BLV <myuser@mail.com>",
+#'          to = "youruser@mail.com",
+#'          cc = "myuser@mail.com",
+#'          subject = paste("Daily report:", Sys.Date()),
+#'          attachment = myPlot)
+#' }
 #' @export
 mailSend <- function(from = "RMail <laresbernardo@gmail.com>",
                      to = "laresbernardo@gmail.com",
-                     cc = NA, bcc = NA,
+                     cc = NULL, bcc = NULL,
                      subject = "Mail from R",
                      text = " \n", 
-                     html = NA,
-                     attachment = NA,
+                     html = NULL,
+                     attachment = NULL,
                      service = "mailgun",
-                     creds = NA,
+                     creds = NULL,
                      quiet = FALSE){
 
   # MailGun documentation:
@@ -38,12 +47,12 @@ mailSend <- function(from = "RMail <laresbernardo@gmail.com>",
   the_body <- list(from = from, to = to, subject = subject)
   
   if (grepl("mailgun", url)) the_body[["o:tag"]] <- "R-email"
-  if (!is.na(cc[1])) the_body[["cc"]] <- cc
-  if (!is.na(bcc[1])) the_body[["bcc"]] <- bcc
-  if (!is.na(text[1])) the_body[["text"]] <- text
-  if (!is.na(html[1])) the_body[["html"]] <- html
+  if (!is.null(cc)) the_body[["cc"]] <- cc
+  if (!is.null(bcc)) the_body[["bcc"]] <- bcc
+  if (!is.null(text)) the_body[["text"]] <- text
+  if (!is.null(html)) the_body[["html"]] <- html
   
-  if (sum(!is.na(attachment)) > 0) {
+  if (!is.null(attachment)) {
     if ("ggplot" %in% class(attachment)) {
       as <- "png"
       file <- paste0(tempdir(), "/attch.", as)
@@ -60,7 +69,7 @@ mailSend <- function(from = "RMail <laresbernardo@gmail.com>",
     }
     the_body[["attachment"]] <- upload_file(file) 
   } else {
-    as <- NA; file <- NA
+    as <- NULL; file <- NULL
   }
   
   # Send email
@@ -71,10 +80,9 @@ mailSend <- function(from = "RMail <laresbernardo@gmail.com>",
   stop_for_status(req)
   
   # Delete temporary files created
-  if (!is.na(file) & as != "attachment") file.remove(file)
+  if (!is.null(file) & !"attachment" %in% as) file.remove(file)
   
-  if (!quiet) {
-    message(paste(subject, "sent to", to, ifelse(!is.na(as), paste("with", as, "file"),""))) 
-  }
+  if (!quiet) message(paste(
+    subject, "sent to", to, ifelse(!is.null(as), paste("with", as, "file"),""))) 
   
 }
